## Comparison of ANOVA and randomised block design

set.seed(12345)

# Specify simulation
N = 120                              # number of subjects
J = 3                                # number of groups
n = N/J                              # group size
Mu <- rep(10, N)                     # grand mean
Alpha <- rep(c(-2, 1, 1), each = n)  # group effect
Pi <-  c(M = 0, S = 3)               # random block effect
Epsilon <- c(M = 0, S = 5)           # random component

# Data frame creation
runs = 100
RandomData <- lapply(1:runs,
                     function(X)
                     {
                       data.frame(A = factor(rep(c("a1", "a2", "a3"),
                                                 each = n)),
                                  Block = factor(rep(paste("Block", 1:n),
                                                     times = J)),
                                  Y = Mu + Alpha + 
                                    rep(rnorm(n, Pi["M"], Pi["S"]),
                                        times = J) +
                                    rnorm(N, Epsilon["M"], Epsilon["S"]))
                     })

# Analysis
pvalues <- t(sapply(RandomData,
                    function(X)
                    {
                      list(CR = summary(aov(Y ~ A, X))[[1]][["Pr(>F)"]][1],
                           RB = summary(aov(Y ~ A + Error(Block),
                                            X))[[2]][[1]][["Pr(>F)"]][[1]])
                    }))

# Results
plot(pvalues[, "CR"], pvalues[, "RB"],
     pch = 16, xlim = c(0, 1), ylim = c(0, 1))
abline(h = .05)
abline(v = .05)
table(ifelse(pvalues[, "CR"] <= .05, "significant", "non-significant"))
table(ifelse(pvalues[, "RB"] <= .05, "significant", "non-significant"))