## Simulation of an experimental design

set.seed(12345)
library(psych)

# Specify simulation
N <- 120
Mu <- rep(5, N)
Alpha <- rep(c(-1,1), each = N/2)
Beta <- rep(c(-.5, .3, .2), times = 2, each = N/6)
AlphaBeta <- rep(c(0, 0, -.1, .6, -.5, 0), each = N/6)
Epsilon <- rnorm(N, 0, 3)

# Model equation
Y <- Mu + Alpha + Beta + AlphaBeta + Epsilon

# Data frame creation
d <- data.frame(Y,
                A = factor(Alpha, labels = c("a1", "a2")),
                B = factor(Beta, labels = c("b1", "b2", "b3")))

# Statistical analysis
describeBy(d$Y,
           group = list(d$A, d$B), 
           mat = TRUE)[c("n", "mean", "sd")]
m <- aov(Y ~ A * B, data = d)
summary(m)
model.tables(m)