## stargazer and texreg tables
source("./Ch8_DataCreation.R")
library(stargazer)
library(texreg)

# Statistical and graphical analysis
psych::describeBy(d$Y, group = list(d$A, d$B))
m1 <- aov(Y ~ A, data = d)
m2 <- aov(Y ~ A + B, data = d)
m3 <- aov(Y ~ A * B, data = d)

# Data frame and summary statistics with stargazer
stargazer(d,
          type = "html",
          out = "DataFrame_SG.html",
          summary = FALSE)

stargazer(d,
          type = "html",
          out = "Descriptives_SG.html",
          summary.stat = c("mean", "n", "sd", "min", "max"))

# Model summaries with stargazer
stargazer(lm(m1),
          type = "html",
          out = "LinearModelTable_m1_SG.html")

stargazer(lm(m1), lm(m2), lm(m3),
          type = "html",
          out = "LinearModelTable_m1m2m3_SG.html")

# Customise stargazer table
stargazer(lm(m1), lm(m2), lm(m3),
          type = "html",
          out = "LinearModelTable_m1m2m3_SG_customised.html",
          column.labels = c("Simple effect",
                            "Main effects",
                            "Main effects + interactions"),
          covariate.labels = c("A", "B 1-2", "B 1-3",
                               "A2:B2", "A2:B3",
                               "Intercept"),
          dep.var.caption = "Response variable",
          dep.var.labels = "Variable Y",
          model.numbers = FALSE,
          single.row = TRUE,
          star.cutoffs = c(.05, .01, .001),
          ci = TRUE,
          digits = 2)

# Model summaries with htmlreg
htmlreg(lm(m1),
        file = "LinearModelTable_m1_HR.html")

htmlreg(list(lm(m1), lm(m2), lm(m3)),
        file = "LinearModelTable_m1m2m3_HR.html")

# Customise htmlreg table
htmlreg(list(lm(m1), lm(m2), lm(m3)),
        file = "LinearModelTable_m1m2m3_HR_customised.html",
        single.row = TRUE,
        stars = c(.01, .05, .1),
        custom.model.names = c("Simple effect",
                               "Main effects",
                               "Main effects + interactions"),
        ci.force = TRUE,
        groups = list("Main factors" = 2:4,
                      "Interactions" = 5:6),
        bold = .05,
        caption = "Linear model summaries",
        caption.above = TRUE)