## Example ggplot2::qplot()
library(ggplot2)

# Data creation
set.seed(12345)
n <- 20
A <- rep(1:3, each = n)
M <- matrix(c(7,  7,  8,
              10, 5,  11,
              14, 5,  10), 3, 3,
            dimnames = list(c("a1", "a2", "a3"),
                            c("X", "Y", "Z")))
d <- data.frame(A = factor(A),
                X = rnorm(length(A), rep(M[,"X"], each = n), 2),
                Y = rnorm(length(A), rep(M[,"Y"], each = n), 2),
                Z = rnorm(length(A), rep(M[,"Z"], each = n), 2))

# Different uses of qplot()
qplot(x = X, y = Y, data = d)
qplot(X, Y, data = d, color = A)
plot(d$X, d$Y, col = as.numeric(d$A), pch = 16)

qplot(X, Y, data = d, geom = c("point", "smooth"))
qplot(A, X, data = d, geom = "boxplot")
qplot(A, X, data = d, geom = c("boxplot", "jitter"), color = A)

qplot(X, Y, data = d, facets = A ~ cut(Z, breaks = 2))
qplot(X, Y, data = d, facets = A ~ .)

myplot <- qplot(X, Y, data = d, facets = cut(Z, breaks = 2) ~ A)
myplot <- myplot + stat_smooth(method = "lm")
myplot
ggsave("myplot.png", myplot)