## grid  Basic example with random data

library(grid)

# Data creation
set.seed(12345)
n <- 20
A <- rep(1:3, each = n)
M <- matrix(c(7,  7,  8,
              10, 5,  11,
              14, 5,  10), 3, 3,
            dimnames = list(c("a1", "a2", "a3"),
                            c("X", "Y", "Z")))
d <- data.frame(A = factor(A),
                X = rnorm(length(A), rep(M[,"X"], each = n), 2),
                Y = rnorm(length(A), rep(M[,"Y"], each = n), 2),
                Z = rnorm(length(A), rep(M[,"Z"], each = n), 2))
rm(A, M, n)

# Create diagram
grid.newpage()
pushViewport(plotViewport(margins = c(5, 4, 2, 2)))
pushViewport(dataViewport(xData = d$X,
                          yData = d$Y))

# Display data and other content
grid.rect()
grid.xaxis()
grid.yaxis()
grid.points(d$X, d$Y,
            name = "dataSymbols",
            pch = 16,
            gp = gpar(col = as.numeric(d$A)*3))
grid.text("Variable X", y = unit(-3, "lines"))
grid.text("Variable Y", x = unit(-3, "lines"), rot = 90)
grid.text("Association between X and Y",
          x = unit(0.1, "npc"), y = unit(0.1, "npc"),
          just = c(0, 0))