## SCB  Data simulation function

if(!exists("SCB_DataSimulation"))
{
  library(mvtnorm)
  SCB_DataSimulation <- function(N = 180,
                                 Mu = 20,
                                 A_effect = c(0, 0, 0),
                                 B_effect = c(0, 0, 0),
                                 Mu_X1 = 5,
                                 Mu_X2 = 15,
                                 Sigma = diag(c(2, 5, rep(5, 12))))
  {
    # Initialise data frame
    d <- data.frame(ID = 1:N,
                    A = rep(c("No intervention",
                              "Enhanced teacher attendance",
                              "Conflict reconciliators"), each = 60),
                    B = rep(c("Primary school",
                              "Secondary school",
                              "Further education"), 3, each = 20),
                    Mu = rep(Mu, N),
                    A_effect = rep(A_effect, each = 60),
                    B_effect = rep(B_effect, times = 3, each = 20))
    
    # Generate correlated random data
    Variates <- c("X1", "X2",
                  "Y1C1", "Y2C1", "Y3C1",
                  "Y1C2", "Y2C2", "Y3C2",
                  "Y1C3", "Y2C3", "Y3C3",
                  "Y1C4", "Y2C4", "Y3C4")
    d[Variates] <- as.data.frame(rmvnorm(N, mean = c(Mu_X1, Mu_X2, rep(0,12)),
                                         sigma = Sigma))
    
    # Generate dependent variables with linear model equation
    d[c("Y1C1", "Y2C1", "Y3C1",
        "Y1C2", "Y2C2", "Y3C2")] <- d$Mu + d$B_effect + d[c("Y1C1", "Y2C1", "Y3C1",
                                                            "Y1C2", "Y2C2", "Y3C2")] 
    d[c("Y1C3", "Y2C3", "Y3C3",
        "Y1C4", "Y2C4", "Y3C4")] <- d$Mu + d$A_effect + d$B_effect + d[c("Y1C3", "Y2C3", "Y3C3",
                                                                         "Y1C4", "Y2C4", "Y3C4")]
    d[c("Mu", "A_effect", "B_effect")] <- NULL
    return(d)
  }
}