## SCB  Power of analysis of covariance by simulation
## Simulation with small effect of factor A and covariate

source("Script/SCB_FUN_DataSimulation.R")
set.seed(12345)

# Set effects and associations
InterventionEffect <- c(.6, -.2, -.4)
CovMat <- diag(c(2, 5, rep(5, 12)))
Covariance <- 2
CovMat[lower.tri(CovMat)] <- Covariance
CovMat[upper.tri(CovMat)] <- Covariance
CovMat[cbind(c(1, 2), c(2, 1))] <- 1

# Generate study replications
SimStat <- t(replicate(100,
                       {
                         d <- SCB_DataSimulation(A_effect = InterventionEffect,
                                                 Sigma = CovMat)
                         m_simple <- anova(lm(Y1C3 ~ A, data = d))
                         m_covariate <- anova(lm(Y1C3 ~ A + X1, data = d))
                         c(Means = with(d, tapply(Y1C3, A, mean)),
                           r = with(d, by(cbind(X1, Y1C3), A, function(x) {cor(x$X1, x$Y1C3)})),
                           p_simple = m_simple$"Pr(>F)"[1],
                           p_covariate = m_covariate$"Pr(>F)"[1])
                       }))
SimStat <- as.data.frame(SimStat)

#View(SimStat)

# Display results
plot(SimStat$p_simple,
     SimStat$p_covariate,
     xlim = c(0, 1),
     ylim = c(0, 1))
abline(h = .05)
abline(v = .05)

# Table of significant p-values
with(SimStat,
     {
       p_breaks <- c(0, .05, 1)
       addmargins(prop.table(table(cut(p_simple, breaks = p_breaks),
                                   cut(p_covariate, breaks = p_breaks),
                                   dnn = c("p_simple", "p_covariate"))))
     })