## UPS  Mean profiles

source("Scripts/UPS_PRE_DataImport.R")

with(UPS,
     {
             # Preparation
             soundvariation <- interaction(sound, variation, sep = " ")
             LevelsOrder <- as.vector(matrix(1:28, nrow = 7, byrow = TRUE))
             levels(soundvariation) <- levels(soundvariation)[LevelsOrder]
             M <- tapply(rating, list(soundvariation, group, gender), mean)
             ftM <- ftable(M, col.vars = c(2, 3))
             M_AcrossGroupsAndGender <- tapply(rating, list(sound, variation), mean)
             M_ByGroupsAndGender <- tapply(rating, list(group, gender), mean)
             
             # Initialise diagram
             png(filename = "Figures/UPS_MeanProfiles.png",
                 width = 1920, height = 1080,
                 pointsize = 20)
             layout(matrix(c(1, 1, 1, 2,
                             1, 1, 1, 2,
                             1, 1, 1, 2,
                             1, 1, 1, 2,
                             1, 1, 1, 2,
                             3, 3, 3, 4), nrow = 6, byrow = TRUE))
             
             par(mar = c(0, 0, 3, .5), oma = c(1, 16, 0, 0))
             
             # Main diagram
             plot.new()
             plot.window(xlim = c(1,6), ylim = c(28, 1))
             box()
             segments(rep(1, 28), 1:28, rep(6, 28), lty = "dotted", col = "grey80", lwd = 2)
             colors = paste0("grey", c(20, 40, 60, 80))
             lapply(as.list(1:4), function(X) lines(ftM[,X], 1:28,
                                                    type = "b", pch = 16,
                                                    col = colors[X],
                                                    lty = X, lwd = 2,
                                                    cex = 1.5))
             
             # Main diagram annotation
             mtext("Unpleasant sounds - Mean profiles by condition", 3, line = 1, at = 1, adj = 0, cex = 1.5)
             mtext(levels(UPS$sound),
                   side = 2, line = 9, at = c(1, 8, 15, 22), las = 1)
             mtext(levels(UPS$variation), 
                   side = 2, line = 1, at = 1:28, las = 1)
             legend(1, 1, c("Female, origin known", "Male, origin known", 
                            "Female, origin unknown", "Male, origin unknown"),
                    cex = 1.5, border = "white",
                    pch = 16, col = colors, lty = 1:4,
                    title = "Condition", title.adj = 0.05)
             
             # Right diagram
             plot.new()
             plot.window(xlim = c(1,6), ylim = c(28, 1))
             box()
             axis(1, cex.axis = 1.2)
             segments(rep(1, 28), 1:28, rep(6, 28),
                      lty = "dotted", col = "grey80", lwd = 2)
             lines(as.numeric(M_AcrossGroupsAndGender), 1:28,
                   type = "b", pch = 16, lwd = 2,
                   cex = 1.5)
             mtext("Mean profile", side = 3, line = 1, at = 1, adj = 0, cex = 1.5)
             mtext("Rating", side = 1, line = 2)
             
             # Bottom diagram
             par(mar = c(3, 0, .5, .5))
             plot.new()
             plot.window(xlim = c(1,6), ylim = c(4.5, .5))
             box()
             axis(1, cex.axis = 1.2)
             segments(rep(1, 4), 1:4, rep(6, 4), lty = "dotted", col = "grey80", lwd = 2)
             points(as.numeric(M_ByGroupsAndGender), 1:4, cex = 1.5, col = "black", pch = 16)
             mtext("Rating", side = 1, line = 2)
             
             # Bottom diagram annotation
             mtext(c("Female", "Male"),
                   side = 2, line = 11, at = c(1, 3), las = 1)
             mtext(rep(c("Origin known", "Origin unknown"), 2),
                   side = 2, line = 1, at = 1:4, las = 1)
             
             # Dummy diagram at the bottom right
             plot.new()
             # Close png graphics device
             dev.off()
     })