## UPS  Response profiles by subject

source("Scripts/UPS_PRE_DataImport.R")

# Preparation
levels(UPS$sound) <- list("Fi" = "Fingernails",
                          "Vo" = "Vomiting",
                          "Ts" = "Tschiritsch",
                          "St" = "Styrofoam")
levels(UPS$variation) <- list("OR" = "Original",
                              "HP" = "High-pass",
                              "LP" = "Low-pass",
                              "BP" = "Band-pass",
                              "BS" = "Band-stop",    
                              "OP" = "Only pitch",
                              "WP" = "Without pitch")
UPS$soundvariation <- interaction(UPS$sound, UPS$variation)
wUPS <- reshape(UPS,
                v.names = "rating",
                timevar = "soundvariation",
                idvar = "subject",
                drop = c("group", "age", "gender",
                         "sound", "variation"), 
                direction = "wide")

# Create figure
pdf(file = "Figures/UPS_ResponseProfilesBySubject.pdf",
    width = 12, height = 16)
layout(matrix(1:96, nrow = 48))
par(mar = c(0,0,0,0), oma = c(6, 3, 3, 1))
lapply(as.list(wUPS$subject), function(X)
{
  plot(matrix(wUPS[wUPS$subject == X, 2:29]),
       
       xlim = c(-1, 28),
       ylim = c(.5, 6.5),
       type = "b",
       pch = 20,
       xaxt = "n",
       yaxt = "n")
  if(X %in% c(78, 130)) axis(1, at = 1:28,
                             labels = names(wUPS)[2:29],
                             las = 2)
  axis(2, at = 1:6, labels = 1:6, line = -4,
       tick = FALSE, cex.axis = .4, las = 1)
  text(-1, 3.5, labels = X, font = 2)
})
mtext("UPS - Response profiles by subject",
      side = 3, outer = TRUE, line = 1)
mtext("Rating of sound pleasantness (1: pleasant to 6: unpleasant)",
      side = 2, outer = TRUE, line = 1)
dev.off()